# metapic

[![PyPI package](https://img.shields.io/pypi/v/metapic)](https://pypi.python.org/pypi/metapic)
[![Build status](https://img.shields.io/travis/luphord/metapic)](https://travis-ci.org/luphord/metapic)

Command line tool for modifying picture metadata from file/folder names and config.

## Features
* `metapic` is a single file Python project

## Install

You can install `metapic` using `pip` with

```bash
pip3 install metapic
```

or you can simply download `metapic.py` and then run it using `python3` with

```bash
python3 metapic.py
```

## History

### 0.1.0 (2020-08-07)
* Created using [cookiecutter-pyscript](https://github.com/luphord/cookiecutter-pyscript)

## Credits

Main developer is luphord <luphord@protonmail.com>. [cookiecutter-pyscript](https://github.com/luphord/cookiecutter-pyscript) is used as project template.
